@@ -17,6 +17,7 @@ from ocr4all_helper_scripts.utils import pageutils, imageutils
 from pathlib import Path
 import sys
 from typing import List, Tuple
+import logging
 
 import numpy as np
 from skimage.measure import find_contours, approximate_polygon
@@ -25,9 +26,8 @@ from scipy.ndimage.filters import gaussian_filter, uniform_filter
 import math
 
 from lxml import etree
-from PIL import Image
+from PIL import Image, ImageChops
 from shapely.geometry import Polygon
-from shapely import affinity
 
 
 # Add printing for every thread
@@ -35,6 +35,7 @@ from threading import Lock
 
 s_print_lock = Lock()
 
+logging.getLogger('shapely.geos').setLevel(logging.CRITICAL)
 
 def s_print(*args, **kwargs):
     with s_print_lock:
@@ -61,7 +62,7 @@ def compute_lines(segmentation: np.ndarray,
         if o is None:
             continue
         if sl.dim1(o) < 2 * scale * filter_strength or sl.dim0(o) < scale * filter_strength:
-            s_print(f"Filter strength of {filter_strength} too high. Skipping detected line object…")
+            s_print(f"Filter strength of {filter_strength} too high. Skipping detected line object...")
             continue
         mask = (segmentation[o] == i + 1)
         if np.amax(mask) == 0:
@@ -119,7 +120,7 @@ def boundary(contour: np.ndarray) -> List[np.float64]:
 
 
 def approximate_smear_polygon(line_mask: np.ndarray, smear_strength: Tuple[float, float] = (1.0, 2.0),
-                              growth: Tuple[float, float] = (1.1, 1.1), max_iterations: int = 1000):
+                              growth: Tuple[float, float] = (1.1, 1.1), max_iterations: int = 50):
     """Approximate a single polygon around high pixels in a mask, via smearing
     """
     padding = 1
@@ -173,7 +174,7 @@ def approximate_smear_polygon(line_mask: np.ndarray, smear_strength: Tuple[float
             # Failsave if contours can't be smeared together after x iterations
             # Draw lines between the extreme points of each contour in order
             if iteration >= max_iterations and len(contours) > 1:
-                s_print(f"Start fail save, since precise line generation took too many iterations ({iteration}).")
+                s_print(f"Start fail save, since precise line generation took too many iterations ({max_iterations}).")
                 extreme_points = []
                 for contour in contours:
                     sorted_x = sorted(contour, key=lambda c: c[0])
@@ -209,7 +210,7 @@ def approximate_smear_polygon(line_mask: np.ndarray, smear_strength: Tuple[float
 def segment(im: Image, scale: float = None, max_blackseps: int = 0, widen_blackseps: int = 10, max_whiteseps: int = 3,
             minheight_whiteseps: int = 10, filter_strength: float = 1.0,
             smear_strength: Tuple[float, float] = (1.0, 2.0), growth: Tuple[float, float] = (1.1, 1.1),
-            orientation: int = 0, fail_save_iterations: int = 1000, vscale: float = 1.0, hscale: float = 1.0,
+            orientation: int = 0, fail_save_iterations: int = 50, vscale: float = 1.0, hscale: float = 1.0,
             minscale: float = 12.0, maxlines: int = 300, threshold: float = 0.2, usegauss: bool = False,
             bounding_box: bool = False):
     """
@@ -223,7 +224,7 @@ def segment(im: Image, scale: float = None, max_blackseps: int = 0, widen_blacks
         raise ValueError('Image is not bi-level')
 
     # rotate input image for vertical lines
-    im_rotated = im.rotate(-1 * orientation, expand=True)
+    im_rotated = im.rotate(-orientation, expand=True, fillcolor="white")
 
     a = np.array(im_rotated.convert('L')) if im_rotated.mode == '1' else np.array(im_rotated)
 
@@ -302,7 +303,7 @@ def pagelineseg(xmlfile: str,
                 smear_strength: Tuple[float, float] = (1.0, 2.0),
                 growth: Tuple[float, float] = (1.1, 1.1),
                 filter_strength: float = 1.0,
-                fail_save_iterations: int = 100,
+                fail_save_iterations: int = 50,
                 maxskew: float = 2.0,
                 skewsteps: int = 8,
                 usegauss: bool = False,
@@ -347,6 +348,11 @@ def pagelineseg(xmlfile: str,
             s_print(f"[{name}] Skew estimate between +/-{maxskew} in {skewsteps} steps. Estimated {orientation}°")
 
         if cropped is not None:
+            # Check whether cropped are is completely white or black and skip if true
+            if not cropped.getbbox() or not ImageChops.invert(cropped).getbbox():
+                s_print(f"[{name}] Skipping fully black / white region...")
+                continue
+
             colors = cropped.getcolors(2)
             if not (colors is not None and len(colors) == 2):
                 cropped = Image.fromarray(nlbin.adaptive_binarize(np.array(cropped)).astype(np.uint8))
